@@ -47,7 +47,10 @@ class MonitoringCache:
 
 class DeviceCoordinator:
     '''
-    Coordinating devices
+    Device coordinator is responsible for coordination, like start recording data
+    from all devices at once, stop recording, triggering (marking data at point), 
+    and terminating devices. 
+    When a device is added to the device coordinator, it will be initialized and prepared for data recording.
     '''
 
     def __init__(self):
@@ -62,9 +65,12 @@ class DeviceCoordinator:
         '''
         Generate an ID for devices that do not have name
 
-        @rtype: str
-        @return device_id
+        Returns
+        -----------
+        str
+            an ID for device
         '''
+
         self.__device_counter += 1
         device_id = "device_{0}".format(self.__device_counter)
         return device_id
@@ -73,18 +79,31 @@ class DeviceCoordinator:
         '''
         Return a list of added devices
 
-        @rtype: list(device)
-        @return a list of added devices
+        Returns
+        -----------
+        List[Device]
+            List of device objects
         '''
+
         return list(self.__devices.values())
 
     def add_device(self, device: Device) -> None:
         '''
         Adds new device to the coordinator and starts it
 
-        @param Device device: a device object
+        Parameters
+        ----------
+        device: Device
+            a device object
+        
+        Example
+        --------
+        >>> my_shimmer = Shimmer3Streaming(name="Shimmer3_sensor", output_path="./output")
+        >>> device_coordinator.add_device(my_shimmer)
 
-        @keyword str name: The name of device
+        See Also
+        ---------
+        add_devices: Adds a list of new devices to the coordinator and starts them
         '''
         assert isinstance(device, Device)
 
@@ -104,24 +123,52 @@ class DeviceCoordinator:
 
     def add_devices(self, devices: List[Device]) -> None:
         '''
-        Adds new devices to the coordinator
+        Adds a list of new devices to the coordinator and starts them
 
-        @param list devices: a list of device object
-        @type devices: list(Device)
+        Parameters
+        ----------
+        devices: List[Device]
+            a list of device objects
+    
+        Example
+        --------
+        >>> my_shimmer = Shimmer3Streaming(name="Shimmer3_sensor",
+                                           output_path="./output")
+        >>> device_coordinator.add_devices([my_shimmer])
+
+        See Also
+        ---------
+        add_device: Adds new device to the coordinator and starts it
         '''
         for device in devices:
             self.add_device(device)
 
     def dispatch(self, message: Message) -> None:
         '''
-        dispatch new message to all devices
+        dispatches a new message to all devices
 
-        @param Message message: a message object object
+        Parameters
+        ----------
+        message: Message
+            a message object
+        
+        Example
+        --------     
+        >>> device_coordinator.dispatch(start_message(experiment_id,
+                                                      stimuli_id))
         '''
+
         for message_queue in self.__queues:
             message_queue.put(message)
 
     def terminate(self):
+        '''
+        sends terminate message to all devices and terminate all processes 
+
+        Example
+        --------     
+        >>> device_coordinator.terminate()
+        '''
         self.dispatch(terminate_message())
         for item in self.__devices.values():
             item.join()
@@ -131,8 +178,15 @@ class DeviceCoordinator:
         Returns latest collected data from all devices.
         Device's data can be anything, depending on the device itself.
 
-        @return: Dict of device name to the collected data.
-        @rtype: Dict[device_name, List[Any]]
+        Returns
+        ---------
+        data : dict[str, list[any]]
+            The keys are device names and values are collected data from the device
+        
+        Note
+        ----
+        This method is being used for real-time monitoring
+
         '''
         cached = self.__monitoring_cache.get_cache()
         if cached:
